Notebooks
========================================================================================
These example notebooks demonstrate how to use the across-client library to interface
with the ACROSS ``core-server`` to retrieve observatory/telescope/instrument metadata,
schedules and observations, and to perform visibility window calculations.

Getting Started with across-client
-----------------------------------
.. toctree::
   :maxdepth: 1

   Getting Started with across-client <pre_executed/getting_started>